/**
 * Copyright (c) 2013-2024 Nikita Koksharov
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.redisson;

import org.redisson.client.protocol.RedisCommand;
import org.redisson.connection.MasterSlaveEntry;

import java.util.Collection;
import java.util.List;

/**
 * 
 * @author Nikita Koksharov
 *
 * @param <T> type of batch result
 * @param <R> type of result
 */
public interface SlotCallback<T, R> {

    default RedisCommand<T> createCommand(List<Object> params) {
        return null;
    }

    default Object[] createKeys(MasterSlaveEntry entry, List<Object> params) {
        return params.toArray();
    }

    default Object[] createParams(List<Object> params) {
        return params.toArray();
    }

    R onResult(Collection<T> result);

}
